# Changelog

## [Unreleased](https://github.com/OpenVoiceOS/ovos_utils/tree/HEAD)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.25a2...HEAD)

**Fixed bugs:**

- fix/syntax\_error [\#64](https://github.com/OpenVoiceOS/ovos_utils/pull/64) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.25a2](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.25a2) (2022-09-08)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.25a1...V0.0.25a2)

**Merged pull requests:**

- Add method to restart arbitrary systemd service [\#63](https://github.com/OpenVoiceOS/ovos_utils/pull/63) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.25a1](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.25a1) (2022-09-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.24...V0.0.25a1)

**Implemented enhancements:**

- add more api methods [\#62](https://github.com/OpenVoiceOS/ovos_utils/pull/62) ([AIIX](https://github.com/AIIX))

## [V0.0.24](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.24) (2022-09-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.24a4...V0.0.24)

## [V0.0.24a4](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.24a4) (2022-09-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.24a3...V0.0.24a4)

**Merged pull requests:**

- add systemctl mycroft restart option [\#61](https://github.com/OpenVoiceOS/ovos_utils/pull/61) ([AIIX](https://github.com/AIIX))

## [V0.0.24a3](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.24a3) (2022-09-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.24a2...V0.0.24a3)

**Implemented enhancements:**

- feat/ovos\_api [\#60](https://github.com/OpenVoiceOS/ovos_utils/pull/60) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.24a2](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.24a2) (2022-08-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.24a1...V0.0.24a2)

**Merged pull requests:**

- Handle exceptions getting cache directory when MemoryTempfile fails \(i.e. in a chroot\) [\#58](https://github.com/OpenVoiceOS/ovos_utils/pull/58) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.24a1](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.24a1) (2022-08-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.23...V0.0.24a1)

**Merged pull requests:**

- Add extend about data method to gui utils [\#57](https://github.com/OpenVoiceOS/ovos_utils/pull/57) ([AIIX](https://github.com/AIIX))

## [V0.0.23](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.23) (2022-07-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.23a7...V0.0.23)

## [V0.0.23a7](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.23a7) (2022-07-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.23a6...V0.0.23a7)

**Implemented enhancements:**

- Skill location utilities [\#55](https://github.com/OpenVoiceOS/ovos_utils/pull/55) ([NeonDaniel](https://github.com/NeonDaniel))

**Merged pull requests:**

- Update release tag workflows to include version change commits [\#56](https://github.com/OpenVoiceOS/ovos_utils/pull/56) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.23a6](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.23a6) (2022-07-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.23a5...V0.0.23a6)

**Merged pull requests:**

- refactor/use ovos\_config package [\#52](https://github.com/OpenVoiceOS/ovos_utils/pull/52) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.23a5](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.23a5) (2022-07-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.23a4...V0.0.23a5)

**Implemented enhancements:**

- port/file\_watcher [\#54](https://github.com/OpenVoiceOS/ovos_utils/pull/54) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.23a4](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.23a4) (2022-07-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.23a3...V0.0.23a4)

**Merged pull requests:**

- Loosen mycroft-messagebus-client dependency to allow 0.10.0 [\#53](https://github.com/OpenVoiceOS/ovos_utils/pull/53) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.23a3](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.23a3) (2022-06-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.23a2...V0.0.23a3)

**Fixed bugs:**

- Prevent raising exception when msm config not present [\#51](https://github.com/OpenVoiceOS/ovos_utils/pull/51) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.23a2](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.23a2) (2022-06-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.23a1...V0.0.23a2)

**Fixed bugs:**

- fix/allow\_LF\_lang\_to\_be\_None [\#50](https://github.com/OpenVoiceOS/ovos_utils/pull/50) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.23a1](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.23a1) (2022-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.22...V0.0.23a1)

**Fixed bugs:**

- fix/screen\_check [\#49](https://github.com/OpenVoiceOS/ovos_utils/pull/49) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.22](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.22) (2022-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.22a3...V0.0.22)

## [V0.0.22a3](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.22a3) (2022-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.22a2...V0.0.22a3)

**Fixed bugs:**

- Fix/full lang [\#48](https://github.com/OpenVoiceOS/ovos_utils/pull/48) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.22a2](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.22a2) (2022-05-31)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.22a1...V0.0.22a2)

**Implemented enhancements:**

- feat/lang\_utils [\#47](https://github.com/OpenVoiceOS/ovos_utils/pull/47) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.22a1](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.22a1) (2022-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.21...V0.0.22a1)

**Implemented enhancements:**

- support ovos-shell [\#45](https://github.com/OpenVoiceOS/ovos_utils/pull/45) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.21](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.21) (2022-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.21a6...V0.0.21)

## [V0.0.21a6](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.21a6) (2022-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.21a5...V0.0.21a6)

**Implemented enhancements:**

- add InputDeviceHelper to detect available inputs on current system [\#44](https://github.com/OpenVoiceOS/ovos_utils/pull/44) ([AIIX](https://github.com/AIIX))

## [V0.0.21a5](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.21a5) (2022-05-12)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.21a4...V0.0.21a5)

**Implemented enhancements:**

- Add widgets helper [\#43](https://github.com/OpenVoiceOS/ovos_utils/pull/43) ([AIIX](https://github.com/AIIX))

## [V0.0.21a4](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.21a4) (2022-05-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.21a3...V0.0.21a4)

**Merged pull requests:**

- refactor/migrate\_adapt\_boilerplate [\#42](https://github.com/OpenVoiceOS/ovos_utils/pull/42) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.21a3](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.21a3) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.21a2...V0.0.21a3)

**Merged pull requests:**

- add sdist [\#41](https://github.com/OpenVoiceOS/ovos_utils/pull/41) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.21a2](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.21a2) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.21a1...V0.0.21a2)

**Merged pull requests:**

- Fix/remove unused dep [\#40](https://github.com/OpenVoiceOS/ovos_utils/pull/40) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.21a1](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.21a1) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.20...V0.0.21a1)

**Fixed bugs:**

- Fix/adapt [\#39](https://github.com/OpenVoiceOS/ovos_utils/pull/39) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.20](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.20) (2022-04-27)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.20a4...V0.0.20)

## [V0.0.20a4](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.20a4) (2022-04-27)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.20a3...V0.0.20a4)

**Implemented enhancements:**

- Adds ovos service api [\#38](https://github.com/OpenVoiceOS/ovos_utils/pull/38) ([AIIX](https://github.com/AIIX))

**Merged pull requests:**

- notify matrix chat on PR merged [\#37](https://github.com/OpenVoiceOS/ovos_utils/pull/37) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.20a3](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.20a3) (2022-03-23)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.20a2...V0.0.20a3)

**Implemented enhancements:**

- Feat/list utils [\#36](https://github.com/OpenVoiceOS/ovos_utils/pull/36) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.20a2](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.20a2) (2022-03-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.20a1...V0.0.20a2)

**Implemented enhancements:**

- Feat/process utils [\#35](https://github.com/OpenVoiceOS/ovos_utils/pull/35) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.20a1](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.20a1) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.19...V0.0.20a1)

**Fixed bugs:**

- Fix/resolve resource file [\#34](https://github.com/OpenVoiceOS/ovos_utils/pull/34) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.19](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.19) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.19a3...V0.0.19)

## [V0.0.19a3](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.19a3) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.19a2...V0.0.19a3)

**Fixed bugs:**

- fix/platform\_detect [\#33](https://github.com/OpenVoiceOS/ovos_utils/pull/33) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.19a2](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.19a2) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.17a6...V0.0.19a2)

**Breaking changes:**

- Refactor/remove deprecated [\#11](https://github.com/OpenVoiceOS/ovos_utils/pull/11) ([JarbasAl](https://github.com/JarbasAl))

**Merged pull requests:**

- Fix/package workflow [\#32](https://github.com/OpenVoiceOS/ovos_utils/pull/32) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.17a6](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.17a6) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.17a5...V0.0.17a6)

**Fixed bugs:**

- Handle stopwatch.stop before started [\#31](https://github.com/OpenVoiceOS/ovos_utils/pull/31) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.17a5](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.17a5) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.18...V0.0.17a5)

**Merged pull requests:**

- Refactor/workflows from template [\#30](https://github.com/OpenVoiceOS/ovos_utils/pull/30) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.18](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.18) (2022-02-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/V0.0.17a4...V0.0.18)

## [V0.0.17a4](https://github.com/OpenVoiceOS/ovos_utils/tree/V0.0.17a4) (2022-02-24)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/0.0.12...V0.0.17a4)

**Implemented enhancements:**

- Feat/diagnostic mode [\#18](https://github.com/OpenVoiceOS/ovos_utils/pull/18) ([NeonJarbas](https://github.com/NeonJarbas))
- fix/play\_audio [\#14](https://github.com/OpenVoiceOS/ovos_utils/pull/14) ([NeonJarbas](https://github.com/NeonJarbas))
- Feat/better stop watch [\#10](https://github.com/OpenVoiceOS/ovos_utils/pull/10) ([JarbasAl](https://github.com/JarbasAl))
- Feat/more file utils [\#9](https://github.com/OpenVoiceOS/ovos_utils/pull/9) ([JarbasAl](https://github.com/JarbasAl))
- add notification api change and style parameter [\#6](https://github.com/OpenVoiceOS/ovos_utils/pull/6) ([AIIX](https://github.com/AIIX))

**Fixed bugs:**

- Fix/core module detection + refactor xdg config path utils [\#28](https://github.com/OpenVoiceOS/ovos_utils/pull/28) ([NeonJarbas](https://github.com/NeonJarbas))
- Fix typo in configuration paths [\#27](https://github.com/OpenVoiceOS/ovos_utils/pull/27) ([NeonDaniel](https://github.com/NeonDaniel))
- Add back colour dependency [\#24](https://github.com/OpenVoiceOS/ovos_utils/pull/24) ([NeonDaniel](https://github.com/NeonDaniel))
- Add user config home to `get_xdg_config_dirs` [\#23](https://github.com/OpenVoiceOS/ovos_utils/pull/23) ([NeonDaniel](https://github.com/NeonDaniel))
- Loosen dependency versions for OVOS image compat [\#16](https://github.com/OpenVoiceOS/ovos_utils/pull/16) ([NeonDaniel](https://github.com/NeonDaniel))
- Ovos conf [\#12](https://github.com/OpenVoiceOS/ovos_utils/pull/12) ([NeonJarbas](https://github.com/NeonJarbas))
- fix/update\_enclosure\_api [\#8](https://github.com/OpenVoiceOS/ovos_utils/pull/8) ([JarbasAl](https://github.com/JarbasAl))
- Fix/nested delete [\#7](https://github.com/OpenVoiceOS/ovos_utils/pull/7) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- Dependency Version specs [\#13](https://github.com/OpenVoiceOS/ovos_utils/issues/13)
- dependencies are duplicated  + add version specs  [\#5](https://github.com/OpenVoiceOS/ovos_utils/issues/5)

**Merged pull requests:**

- feat/packaging workflows [\#29](https://github.com/OpenVoiceOS/ovos_utils/pull/29) ([JarbasAl](https://github.com/JarbasAl))
- Update license\_tests.yml [\#26](https://github.com/OpenVoiceOS/ovos_utils/pull/26) ([NeonJarbas](https://github.com/NeonJarbas))
- Feat/pypi workflow [\#25](https://github.com/OpenVoiceOS/ovos_utils/pull/25) ([NeonJarbas](https://github.com/NeonJarbas))
- feat/license tests workflow [\#22](https://github.com/OpenVoiceOS/ovos_utils/pull/22) ([JarbasAl](https://github.com/JarbasAl))
- refactor/replace\_pyxdg [\#21](https://github.com/OpenVoiceOS/ovos_utils/pull/21) ([NeonJarbas](https://github.com/NeonJarbas))
- refactor/bump\_requests [\#20](https://github.com/OpenVoiceOS/ovos_utils/pull/20) ([NeonJarbas](https://github.com/NeonJarbas))
- refactor/deprecate\_inflection [\#19](https://github.com/OpenVoiceOS/ovos_utils/pull/19) ([NeonJarbas](https://github.com/NeonJarbas))
- Refactor requirements to read from files [\#15](https://github.com/OpenVoiceOS/ovos_utils/pull/15) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.12](https://github.com/OpenVoiceOS/ovos_utils/tree/0.0.12) (2021-11-04)

[Full Changelog](https://github.com/OpenVoiceOS/ovos_utils/compare/25fe462e3c19a58f32dc1fd940bf7c96fc18e6de...0.0.12)

**Implemented enhancements:**

- release0.0.12/extract get\_local\_settings and save\_settings from core [\#4](https://github.com/OpenVoiceOS/ovos_utils/pull/4) ([JarbasAl](https://github.com/JarbasAl))
- Adds checked path to log that root config path was not found [\#3](https://github.com/OpenVoiceOS/ovos_utils/pull/3) ([NeonDaniel](https://github.com/NeonDaniel))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
